@@ -14,6 +14,7 @@
 #include <caml/fail.h>
 #include <caml/callback.h>
 #include <caml/signals.h>
+#include <stdint.h>
 #include <libusb.h>
 #include <poll.h>
 #include <string.h>
@@ -140,9 +141,24 @@ static void ml_usb_remove_pollfd(int fd, void *user_data)
 
 CAMLprim value ml_usb_init()
 {
+
+  const struct libusb_pollfd** pollfds = NULL;
+
+  int i = 0;
+
   int res = libusb_init(NULL);
   if (res) ml_usb_error(res, "init");
 
+  pollfds = libusb_get_pollfds(NULL);
+
+  if (pollfds) {
+    for (i = 0; pollfds[i] != NULL; i++ ) {
+      ml_usb_add_pollfd(pollfds[i]->fd, pollfds[i]->events, NULL);
+    }
+
+    free(pollfds);
+  }
+
   libusb_set_pollfd_notifiers(NULL,
                               ml_usb_add_pollfd,
                               ml_usb_remove_pollfd,
